==> jc-1.4.0.tar.gz: org/xml/sax/ext/Locator2Impl.h <==
// public class org.xml.sax.ext.Locator2Impl

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class cf4701f676c19ec2 org_xml_sax_ext_Locator2Impl
// @dep_class b459788dc8d17cb0 org_xml_sax_helpers_LocatorImpl

// header file dependencies
// @dep_header org_xml_sax_helpers_LocatorImpl

#include "org/xml/sax/helpers/LocatorImpl.h"

#ifndef _JC_org_xml_sax_ext_Locator2Impl_H_
#define _JC_org_xml_sax_ext_Locator2Impl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Locator$object;

// Typedefs
typedef struct _jc_org_xml_sax_ext_Locator2Impl$sub_refs	_jc_org_xml_sax_ext_Locator2Impl$sub_refs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs	_jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$refs	_jc_org_xml_sax_ext_Locator2Impl$refs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$nonrefs	_jc_org_xml_sax_ext_Locator2Impl$nonrefs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$object	_jc_org_xml_sax_ext_Locator2Impl$object;

typedef const struct _jc_org_xml_sax_ext_Locator2Impl$vmethods	_jc_org_xml_sax_ext_Locator2Impl$vmethods;
typedef const struct _jc_org_xml_sax_ext_Locator2Impl$vtable	_jc_org_xml_sax_ext_Locator2Impl$vtable;
typedef const struct _jc_org_xml_sax_ext_Locator2Impl$vtype	_jc_org_xml_sax_ext_Locator2Impl$vtype;

// Constructors
extern void _jc_org_xml_sax_ext_Locator2Impl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *);
extern void _jc_org_xml_sax_ext_Locator2Impl$method$_init$31a1afb75f5bd29a(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_ext_Locator2Impl$method$getEncoding$03c43fcfdc25c716(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_ext_Locator2Impl$method$getXMLVersion$65144c0a0f06025e(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *);
extern void _jc_org_xml_sax_ext_Locator2Impl$method$setEncoding$f931920c5b28493d(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_xml_sax_ext_Locator2Impl$method$setXMLVersion$e0730dbde16f3d51(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *);

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$getEncoding$03c43fcfdc25c716;
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$getXMLVersion$65144c0a0f06025e;
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$setEncoding$f931920c5b28493d;
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$setXMLVersion$e0730dbde16f3d51;

// Virtual methods structure
struct _jc_org_xml_sax_ext_Locator2Impl$vmethods {
	struct _jc_java_lang_String$object	*(*getEncoding$03c43fcfdc25c716)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *);
	struct _jc_java_lang_String$object	*(*getXMLVersion$65144c0a0f06025e)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *);
	void	(*setEncoding$f931920c5b28493d)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *);
	void	(*setXMLVersion$e0730dbde16f3d51)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *);
};

// Vtable
struct _jc_org_xml_sax_ext_Locator2Impl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_LocatorImpl$vmethods	org_xml_sax_helpers_LocatorImpl;
	_jc_org_xml_sax_ext_Locator2Impl$vmethods	org_xml_sax_ext_Locator2Impl;
};

// Vtype
struct _jc_org_xml_sax_ext_Locator2Impl$vtype {
	_jc_type			type;
	_jc_org_xml_sax_ext_Locator2Impl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_ext_Locator2Impl$sub_refs {
	struct _jc_java_lang_String$object	*encoding;
	struct _jc_java_lang_String$object	*version;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_ext_Locator2Impl$refs {
    _jc_org_xml_sax_ext_Locator2Impl$sub_refs	org_xml_sax_ext_Locator2Impl;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_refs	org_xml_sax_helpers_LocatorImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_ext_Locator2Impl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_nonrefs	org_xml_sax_helpers_LocatorImpl;
    _jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs	org_xml_sax_ext_Locator2Impl;
};

// Object instance structure
struct _jc_org_xml_sax_ext_Locator2Impl$object {
	_jc_org_xml_sax_ext_Locator2Impl$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_ext_Locator2Impl$vtype	*vtype;
	_jc_org_xml_sax_ext_Locator2Impl$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_ext_Locator2Impl$vtype _jc_org_xml_sax_ext_Locator2Impl$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_ext_Locator2Impl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_ext_Locator2Impl$class_object;

#endif	/* _JC_org_xml_sax_ext_Locator2Impl_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/ext/Locator2Impl.h <==
// public class org.xml.sax.ext.Locator2Impl

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class cf4701f676c19ec2 org_xml_sax_ext_Locator2Impl
// @dep_class b459788dc8d17cb0 org_xml_sax_helpers_LocatorImpl

// header file dependencies
// @dep_header org_xml_sax_helpers_LocatorImpl

#include "org/xml/sax/helpers/LocatorImpl.h"

#ifndef _JC_org_xml_sax_ext_Locator2Impl_H_
#define _JC_org_xml_sax_ext_Locator2Impl_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Locator$object;

// Typedefs
typedef struct _jc_org_xml_sax_ext_Locator2Impl$sub_refs	_jc_org_xml_sax_ext_Locator2Impl$sub_refs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs	_jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$refs	_jc_org_xml_sax_ext_Locator2Impl$refs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$nonrefs	_jc_org_xml_sax_ext_Locator2Impl$nonrefs;
typedef struct _jc_org_xml_sax_ext_Locator2Impl$object	_jc_org_xml_sax_ext_Locator2Impl$object;

typedef const struct _jc_org_xml_sax_ext_Locator2Impl$vmethods	_jc_org_xml_sax_ext_Locator2Impl$vmethods;
typedef const struct _jc_org_xml_sax_ext_Locator2Impl$vtable	_jc_org_xml_sax_ext_Locator2Impl$vtable;
typedef const struct _jc_org_xml_sax_ext_Locator2Impl$vtype	_jc_org_xml_sax_ext_Locator2Impl$vtype;

// Constructors
extern void _jc_org_xml_sax_ext_Locator2Impl$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_ext_Locator2Impl$method$_init$31a1afb75f5bd29a(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_ext_Locator2Impl$method$getEncoding$03c43fcfdc25c716(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_ext_Locator2Impl$method$getXMLVersion$65144c0a0f06025e(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_ext_Locator2Impl$method$setEncoding$f931920c5b28493d(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_ext_Locator2Impl$method$setXMLVersion$e0730dbde16f3d51(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$getEncoding$03c43fcfdc25c716;
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$getXMLVersion$65144c0a0f06025e;
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$setEncoding$f931920c5b28493d;
extern _jc_method _jc_org_xml_sax_ext_Locator2Impl$method_info$setXMLVersion$e0730dbde16f3d51;

// Virtual methods structure
struct _jc_org_xml_sax_ext_Locator2Impl$vmethods {
	struct _jc_java_lang_String$object	*(*getEncoding$03c43fcfdc25c716)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getXMLVersion$65144c0a0f06025e)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *) _JC_JCNI_ATTR;
	void	(*setEncoding$f931920c5b28493d)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setXMLVersion$e0730dbde16f3d51)(_jc_env *, struct _jc_org_xml_sax_ext_Locator2Impl$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_xml_sax_ext_Locator2Impl$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_org_xml_sax_helpers_LocatorImpl$vmethods	org_xml_sax_helpers_LocatorImpl;
	_jc_org_xml_sax_ext_Locator2Impl$vmethods	org_xml_sax_ext_Locator2Impl;
};

// Vtype
struct _jc_org_xml_sax_ext_Locator2Impl$vtype {
	_jc_type			type;
	_jc_org_xml_sax_ext_Locator2Impl$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_ext_Locator2Impl$sub_refs {
	struct _jc_java_lang_String$object	*encoding;
	struct _jc_java_lang_String$object	*version;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_ext_Locator2Impl$refs {
    _jc_org_xml_sax_ext_Locator2Impl$sub_refs	org_xml_sax_ext_Locator2Impl;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_refs	org_xml_sax_helpers_LocatorImpl;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_ext_Locator2Impl$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_org_xml_sax_helpers_LocatorImpl$sub_nonrefs	org_xml_sax_helpers_LocatorImpl;
    _jc_org_xml_sax_ext_Locator2Impl$sub_nonrefs	org_xml_sax_ext_Locator2Impl;
};

// Object instance structure
struct _jc_org_xml_sax_ext_Locator2Impl$object {
	_jc_org_xml_sax_ext_Locator2Impl$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_ext_Locator2Impl$vtype	*vtype;
	_jc_org_xml_sax_ext_Locator2Impl$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_ext_Locator2Impl$vtype _jc_org_xml_sax_ext_Locator2Impl$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_ext_Locator2Impl, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_ext_Locator2Impl$class_object;

#endif	/* _JC_org_xml_sax_ext_Locator2Impl_H_ */
